@@ -24,3 +24,17 @@ def build_repr(inst):
         if val:
             accum.append('%r: %r' % (f, val))
     return '{' + ', '.join(accum) + '}'
+
+
+def max_len(text, n):
+    if len(text) <= n:
+        return text
+    return text[:n - 3] + '...'
+
+
+def ensure_string(val):
+    if isinstance(val, str):
+        return val
+    elif isinstance(val, bytes):
+        return val.decode('utf-8')
+    return str(val)
