@@ -3,7 +3,8 @@ from .util import set_fields
 
 class VersionInfo(object):
     def __init__(self, obj):
-        set_fields(self, obj, ['bodySize', 'bodyRows', 'bodyFormat', 'numErrors', 'commitTime'])
+        set_fields(self, obj, ['bodySize', 'bodyRows', 'bodyFormat',
+                               'numErrors', 'metaTitle', 'commitTime'])
 
     def __repr__(self):
         return 'VersionInfo()'
